Skip to contents

Data frame of proper tissue codes for each ome/tissue, which is especially important to get a physiological understanding of different types of tissues (e.g. whole blood vs pbmcs)

Usage

OME_TISSUE_CODE

Format

A data.frame object with a tissue, the relevant BIC tissue code, and the ome for the given tissue.