Skip to contents

A character vector containing the targeted and untargeted metabolomics platforms.

Usage

metab_only_list()

Value

A character vector containing the targeted and untargeted metabolomics platforms.

Examples

metab_only_list()
#>  [1] "metab-u-hilicpos"  "metab-u-ionpneg"   "metab-u-lrpneg"   
#>  [4] "metab-u-lrppos"    "metab-u-rpneg"     "metab-u-rppos"    
#>  [7] "metab-t-amines"    "metab-t-conv"      "metab-t-imm-crt"  
#> [10] "metab-t-oxylipneg" "metab-t-tca"       "metab-t-nuc"      
#> [13] "metab-t-acoa"      "metab-t-ka"