Tissue codes relevant for a given ome
OME_TISSUE_CODE.RdData frame of proper tissue codes for each ome/tissue, which is especially important to get a physiological understanding of different types of tissues (e.g. whole blood vs pbmcs)
OME_TISSUE_CODE.RdData frame of proper tissue codes for each ome/tissue, which is especially important to get a physiological understanding of different types of tissues (e.g. whole blood vs pbmcs)