Check package installation
check_package_installation.RdSeveral secondary R packages are used and it's preferable to install them only if they are needed. Placing this check in the body of a function will provide helpful instructions for cases when a user attempts to run a function but doesn't have the required suggested package(s). (The main inspiration of this was because a lot of people had issues installing some packages needed for only specific analysis)