Bubble heatmap of CAMERA-PR or ORA results from fuzzy c-means clustering
plot_cluster_enrichment.RdGenerate a bubble heatmap from the results of nonparametric CAMERA-PR or ORA applied to the output of fuzzy c-means clustering.
Arguments
- x
a
data.frame. EitherFCM_CAMERAorFCM_ORA.- set_ids
character or
NULL; one or more ofx$set_id. The datasetxwill be filtered to these sets. IfNULL, then_topmost significant sets from each contrast will be selected.- selected_tissues
character; one or more tissues that will be used to create the heatmap. If multiple tissues are selected, only those terms tested in at least two tissues will be plotted.
- selected_ome
character; the ome that will be used to create the heatmap.
- padj_cutoff
numeric; cutoff in terms of p-value for an asterisk to be included
- n_top
integer; if
set_idsisNULL, then_topmost significant molecular signatures from each tissue and cluster will be selected.- column_title
character or
NULL; title for the heatmap.- filename
character; path to a PDF file to save the heatmap.