Fuzzy C-Means (FCM) Clustering
run_cmeans.RdFuzzy c-means clustering of features by the shape of their
z-score trajectories across the "exercise_with_controls" contrasts
(the two during contrasts excluded). The pre-computed
FCM_CLUSTERS was built
with the default arguments.
Arguments
- DA_list
list; a named list of
data.frameobjects, each containing differential analysis results for a specific tissue/assay combination. The list is nested, with tissues at the top level and omes within tissues, or already flattened with names of the form"tissue.assay". IfNULL(default), the differential analysis results will be generated withload_differential_analysis. Unless wishing to analyze DA results that are not in MotrpacHumanPreSuspensionAnalysis, this should remainNULL.- selected_tissues
character; passed to
load_differential_analysis. One or more of the following:"all","muscle","adipose", or"blood".- selected_omes
character; one or more of
"transcript-rna-seq","prot-pr","prot-ol","prot-ph", or"metab".- num_clusters_adipose, num_clusters_blood, num_clusters_muscle
integer; the number of clusters for each tissue, a single value each. Defaults to 13 for adipose, 12 for blood, and 12 for muscle, the values used for
FCM_CLUSTERS. They were chosen from a sweep of cluster numbers in the motrpac-human-presuspension-repro pipeline (step 13), which plots the minimum centroid distance and related diagnostics for each tissue.- modality
character; which exercise modalities should be used for FCM? One of
"both","Endur", or"Resist".
Value
A named list of objects where names are tissues. Each object is of
class "fclust" with additional list component "input" for the
matrix of scaled z-scores used as input for FCM (both modalities included,
even when modality != "both").
Examples
if (FALSE) { # \dontrun{
x1 <- run_cmeans()
names(x1) # list available components
# Reuse differential analysis results already in memory
DA_list <- load_differential_analysis(selected_tissues = "adipose")
x2 <- run_cmeans(DA_list = DA_list,
selected_tissues = "adipose")
# FCM for a single modality
x3 <- run_cmeans(selected_tissues = "adipose",
modality = "Endur")
} # }