Scales data and runs clustering to find groups to form networks
from for the scion function
Usage
scion_run_cmeans(DA_Input_Cmeans, num_clusters = 13)
Arguments
- DA_Input_Cmeans
list of differential results that fits the cmeans function
- num_clusters
numeric; number of desired clusters.
Value
A list with relevant clustering result information